var servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime =
[
    [ "com::sun::star::text::TextField", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#ac5c12dd117b70431d72eeb6ab9507fd2", null ],
    [ "CurrentPresentation", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#a632a1788f5e2e009b3809bbb266e39a0", null ],
    [ "DateTimeValue", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#a6831c7d545ee2024d776a2d8119c4bdf", null ],
    [ "IsFixed", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#a57c3add6784f715a9bed21c3318f41ba", null ],
    [ "IsFixedLanguage", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#a6d2a6e8913ac03867d5217d922acbaa7", null ],
    [ "NumberFormat", "servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html#a47bcb1c1fb4b08615d0866e989fd6f87", null ]
];